@@ -39,7 +39,7 @@ class TestQueue(TestCase):
             for i in nums:
                 await queue.put(i)
 
-            await queue.done()
+            await queue.worker_done()
 
         processes = pl.task.start_workers(worker)
 
@@ -59,7 +59,7 @@ class TestQueue(TestCase):
             for i in nums:
                 await queue.put(i)
 
-            await queue.done()
+            await queue.worker_done()
 
         processes = pl.task.start_workers(worker)
 
@@ -79,7 +79,7 @@ class TestQueue(TestCase):
             for i in nums:
                 await queue.put(i)
 
-            await queue.done()
+            await queue.worker_done()
 
         processes = pl.task.start_workers(worker)
 
@@ -98,14 +98,14 @@ class TestQueue(TestCase):
             for i in nums:
                 await queue.put(i)
 
-            await queue.done()
+            await queue.worker_done()
 
         processes = pl.task.start_workers(worker)
 
         await asyncio.sleep(0.01)
 
         if len(nums) > 0:
-            x = queue.get_nowait()
+            x = queue._get_nowait()
             assert x == nums[0]
 
     @hp.given(nums=st.lists(st.integers()))
@@ -118,7 +118,7 @@ class TestQueue(TestCase):
             for i in nums:
                 await queue.put(i)
 
-            queue.done_nowait()
+            queue.worker_done_nowait()
 
         processes = pl.task.start_workers(worker)
 
@@ -138,7 +138,7 @@ class TestQueue(TestCase):
             for i in nums:
                 await queue.put(i)
 
-            await queue.done()
+            await queue.worker_done()
 
         processes = pl.task.start_workers(worker, n_workers=n_workers)
 
@@ -159,7 +159,7 @@ class TestQueue(TestCase):
             for i in nums:
                 await queue.put(i)
 
-            await queue.done()
+            await queue.worker_done()
 
         processes = pl.task.start_workers(worker, n_workers=n_workers)
 
@@ -352,7 +352,7 @@ class TestOutputQueues(TestCase):
 
         queues.put_nowait(3)
 
-        x = queue.get_nowait()
+        x = queue._get_nowait()
 
         assert isinstance(queues, list)
         assert x == 3
@@ -378,11 +378,11 @@ class TestOutputQueues(TestCase):
 
         queues.append(queue)
 
-        await queues.done()
+        await queues.worker_done()
 
         x = await queue.get()
 
-        assert isinstance(x, pypeln_utils.Done)
+        assert isinstance(x, pl.utils.Done)
 
     def test_done_nowait(self):
         queues: pl.task.OutputQueues[int] = pl.task.OutputQueues()
@@ -390,11 +390,10 @@ class TestOutputQueues(TestCase):
 
         queues.append(queue)
 
-        queues.done_nowait()
+        queues.worker_done_nowait()
 
-        x = queue.get_nowait()
-
-        assert isinstance(x, pypeln_utils.Done)
+        with pytest.raises(asyncio.QueueEmpty):
+            x = queue._get_nowait()
 
     @run_test_async
     async def test_stop(self):
