@@ -1,14 +1,34 @@
 import asyncio
-from concurrent.futures import Future
 import functools
 import threading
 import typing as tp
+from concurrent.futures import Future
 
 from pypeln import utils as pypeln_utils
 
 
-def Namespace(**kwargs) -> tp.Any:
-    return pypeln_utils.Namespace(**kwargs)
+class Namespace:
+    def __init__(self, **kwargs):
+        self.__dict__["_namespace"] = pypeln_utils._Namespace(**kwargs)
+        self.__dict__["_lock"] = asyncio.Lock()
+
+    def __getattr__(self, key) -> tp.Any:
+        if key in ("_namespace", "_lock"):
+            raise AttributeError()
+
+        return getattr(self._namespace, key)
+
+    def __setattr__(self, key, value) -> None:
+        if key in ("_namespace", "_lock"):
+            raise AttributeError()
+
+        setattr(self._namespace, key, value)
+
+    async def __aenter__(self):
+        await self._lock.acquire()
+
+    async def __aexit__(self, *args):
+        self._lock.release()
 
 
 def get_running_loop() -> asyncio.AbstractEventLoop:
@@ -22,7 +42,8 @@ def get_running_loop() -> asyncio.AbstractEventLoop:
     if not loop.is_running():
 
         def run():
-            loop.run_forever()
+            if not loop.is_running():
+                loop.run_forever()
 
         thread = threading.Thread(target=run)
         thread.daemon = True
@@ -42,7 +63,8 @@ def run_coroutine_in_loop(
 
 
 def run_function_in_loop(
-    f: tp.Callable[[], tp.Any], loop: tp.Optional[asyncio.AbstractEventLoop] = None,
+    f: tp.Callable[[], tp.Any],
+    loop: tp.Optional[asyncio.AbstractEventLoop] = None,
 ) -> asyncio.Handle:
     loop = loop if loop else get_running_loop()
 
