@@ -43,10 +43,12 @@ def test_basic(nums):
             await worker.stage_params.output_queues.put(x)
 
     stage_params: pl.task.StageParams = mock.Mock(
-        input_queue=input_queue, output_queues=output_queues, total_workers=1,
+        input_queue=input_queue,
+        output_queues=output_queues,
+        total_workers=1,
     )
 
-    worker = pl.task.Worker(
+    worker = pl.task.Worker.create(
         process_fn=CustomProcess(f),
         stage_params=stage_params,
         main_queue=output_queue,
@@ -81,10 +83,12 @@ async def test_basic_async(nums):
             await worker.stage_params.output_queues.put(x)
 
     stage_params: pl.task.StageParams = mock.Mock(
-        input_queue=input_queue, output_queues=output_queues, total_workers=1,
+        input_queue=input_queue,
+        output_queues=output_queues,
+        total_workers=1,
     )
 
-    worker = pl.task.Worker(
+    worker = pl.task.Worker.create(
         process_fn=CustomProcess(f),
         stage_params=stage_params,
         main_queue=output_queue,
@@ -114,10 +118,12 @@ def test_raises():
         raise MyException()
 
     stage_params: pl.task.StageParams = mock.Mock(
-        input_queue=input_queue, output_queues=output_queues, total_workers=1,
+        input_queue=input_queue,
+        output_queues=output_queues,
+        total_workers=1,
     )
 
-    worker = pl.task.Worker(
+    worker = pl.task.Worker.create(
         process_fn=CustomProcess(f),
         stage_params=stage_params,
         main_queue=output_queue,
@@ -147,7 +153,9 @@ async def test_raises_async():
         raise MyException()
 
     stage_params: pl.task.StageParams = mock.Mock(
-        input_queue=input_queue, output_queues=output_queues, total_workers=1,
+        input_queue=input_queue,
+        output_queues=output_queues,
+        total_workers=1,
     )
 
     worker = pl.task.Worker(
@@ -170,7 +178,7 @@ async def test_raises_async():
     assert worker.is_done
 
 
-def test_timeout():
+def test_timeout_base():
     input_queue = pl.task.IterableQueue()
     output_queue = pl.task.IterableQueue()
     output_queues = pl.task.OutputQueues([output_queue])
@@ -178,37 +186,42 @@ def test_timeout():
 
     async def f(worker: pl.task.Worker):
         async def task():
-            await asyncio.sleep(0.01)
+            for i in range(1000):
+                await asyncio.sleep(0.01)
             namespace.x = 1
 
         await worker.tasks.put(task)
 
     stage_params: pl.task.StageParams = mock.Mock(
-        input_queue=input_queue, output_queues=output_queues, total_workers=1,
+        input_queue=input_queue,
+        output_queues=output_queues,
+        total_workers=1,
     )
 
-    worker = pl.task.Worker(
+    timeout = 0.001
+
+    worker = pl.task.Worker.create(
         process_fn=CustomProcess(f),
         stage_params=stage_params,
         main_queue=output_queue,
-        timeout=0.001,
+        timeout=timeout,
         on_start=None,
         on_done=None,
         f_args=[],
-        tasks=pl.task.TaskPool.create(workers=1),
+        tasks=pl.task.TaskPool.create(workers=1, timeout=timeout),
     )
 
+    worker.start()
+
     # wait for worker to start
     time.sleep(0.02)
 
-    worker.start()
-
     while len(worker.tasks.tasks) > 0:
         time.sleep(0.001)
 
     assert namespace.x == 0
 
-    time.sleep(0.02)
+    time.sleep(0.1)
 
     assert worker.is_done
 
@@ -228,18 +241,25 @@ async def test_timeout_async():
         await worker.tasks.put(task)
 
     stage_params: pl.task.StageParams = mock.Mock(
-        input_queue=input_queue, output_queues=output_queues, total_workers=1,
+        input_queue=input_queue,
+        output_queues=output_queues,
+        total_workers=1,
     )
 
-    worker = pl.task.Worker(
+    timeout = 0.001
+
+    worker = pl.task.Worker.create(
         process_fn=CustomProcess(f),
         stage_params=stage_params,
         main_queue=output_queue,
-        timeout=0.001,
+        timeout=timeout,
         on_start=None,
         on_done=None,
         f_args=[],
-        tasks=pl.task.TaskPool.create(workers=1),
+        tasks=pl.task.TaskPool.create(
+            workers=1,
+            timeout=timeout,
+        ),
     )
 
     # wait for worker to start
@@ -247,7 +267,8 @@ async def test_timeout_async():
 
     worker.start()
 
-    await worker.tasks.join()
+    while len(worker.tasks.tasks) > 0:
+        await asyncio.sleep(0.01)
 
     assert namespace.x == 0
 
@@ -270,18 +291,22 @@ def test_no_timeout():
         await worker.tasks.put(task)
 
     stage_params: pl.task.StageParams = mock.Mock(
-        input_queue=input_queue, output_queues=output_queues, total_workers=1,
+        input_queue=input_queue,
+        output_queues=output_queues,
+        total_workers=1,
     )
 
-    worker = pl.task.Worker(
+    timeout = 0.0
+
+    worker = pl.task.Worker.create(
         process_fn=CustomProcess(f),
         stage_params=stage_params,
         main_queue=output_queue,
-        timeout=0.02,
+        timeout=timeout,
         on_start=None,
         on_done=None,
         f_args=[],
-        tasks=pl.task.TaskPool.create(workers=0),
+        tasks=pl.task.TaskPool.create(workers=0, timeout=timeout),
     )
     worker.start()
 
@@ -310,18 +335,22 @@ async def test_no_timeout_async():
 
         await worker.tasks.put(task)
 
+    timeout = 0.02
+
     stage_params: pl.task.StageParams = mock.Mock(
-        input_queue=input_queue, output_queues=output_queues, total_workers=1,
+        input_queue=input_queue,
+        output_queues=output_queues,
+        total_workers=1,
     )
-    worker = pl.task.Worker(
+    worker = pl.task.Worker.create(
         process_fn=CustomProcess(f),
         stage_params=stage_params,
         main_queue=output_queue,
-        timeout=0.02,
+        timeout=timeout,
         on_start=None,
         on_done=None,
         f_args=[],
-        tasks=pl.task.TaskPool.create(workers=0),
+        tasks=pl.task.TaskPool.create(workers=0, timeout=timeout),
     )
     worker.start()
 
@@ -345,10 +374,12 @@ def test_del1():
             await asyncio.sleep(0.01)
 
     stage_params: pl.task.StageParams = mock.Mock(
-        input_queue=input_queue, output_queues=output_queues, total_workers=1,
+        input_queue=input_queue,
+        output_queues=output_queues,
+        total_workers=1,
     )
 
-    worker = pl.task.Worker(
+    worker = pl.task.Worker.create(
         process_fn=CustomProcess(f),
         stage_params=stage_params,
         main_queue=output_queue,
@@ -365,7 +396,7 @@ def test_del1():
     time.sleep(0.01)
 
     worker.stop()
-    time.sleep(0.02)
+    time.sleep(0.2)
 
     assert task.cancelled()
     assert worker.is_done
@@ -382,10 +413,12 @@ async def test_del1_async():
             await asyncio.sleep(0.01)
 
     stage_params: pl.task.StageParams = mock.Mock(
-        input_queue=input_queue, output_queues=output_queues, total_workers=1,
+        input_queue=input_queue,
+        output_queues=output_queues,
+        total_workers=1,
     )
 
-    worker = pl.task.Worker(
+    worker = pl.task.Worker.create(
         process_fn=CustomProcess(f),
         stage_params=stage_params,
         main_queue=output_queue,
@@ -402,7 +435,7 @@ async def test_del1_async():
     await asyncio.sleep(0.01)
 
     worker.stop()
-    await asyncio.sleep(0.01)
+    await asyncio.sleep(0.2)
 
     assert task.cancelled()
     assert worker.is_done
@@ -419,14 +452,18 @@ def test_del3():
                 await asyncio.sleep(0.01)
 
         stage_params: pl.task.StageParams = mock.Mock(
-            input_queue=input_queue, output_queues=output_queues, total_workers=1,
+            input_queue=input_queue,
+            output_queues=output_queues,
+            total_workers=1,
         )
 
         stage_params: pl.task.StageParams = mock.Mock(
-            input_queue=input_queue, output_queues=output_queues, total_workers=1,
+            input_queue=input_queue,
+            output_queues=output_queues,
+            total_workers=1,
         )
 
-        worker = pl.task.Worker(
+        worker = pl.task.Worker.create(
             process_fn=CustomProcess(f),
             stage_params=stage_params,
             main_queue=output_queue,
@@ -462,10 +499,12 @@ async def test_del3_async():
                 await asyncio.sleep(0.01)
 
         stage_params: pl.task.StageParams = mock.Mock(
-            input_queue=input_queue, output_queues=output_queues, total_workers=1,
+            input_queue=input_queue,
+            output_queues=output_queues,
+            total_workers=1,
         )
 
-        worker = pl.task.Worker(
+        worker = pl.task.Worker.create(
             process_fn=CustomProcess(f),
             stage_params=stage_params,
             main_queue=output_queue,
