@@ -27,7 +27,7 @@ class TestQueue(TestCase):
             for i in nums:
                 queue.put(i)
 
-            queue.done()
+            queue.worker_done()
 
         processes = pl.thread.start_workers(worker)
 
@@ -47,7 +47,7 @@ class TestQueue(TestCase):
             for i in nums:
                 queue.put(i)
 
-            queue.done()
+            queue.worker_done()
 
         processes = pl.thread.start_workers(worker, n_workers=n_workers)
 
@@ -140,11 +140,12 @@ class TestOutputQueues(TestCase):
 
         queues.append(queue)
 
-        queues.done()
+        queues.worker_done()
 
-        x = queue.get()
+        with pytest.raises(pl.thread.queue.Empty):
+            x = queue.get(timeout=0.01)
 
-        assert isinstance(x, pypeln_utils.Done)
+        assert all(q.is_done() for q in queues)
 
     def test_stop(self):
         queues: pl.thread.OutputQueues[int] = pl.thread.OutputQueues()
@@ -168,4 +169,4 @@ class TestOutputQueues(TestCase):
 
         queues.kill()
 
-        assert queue.namespace.remaining == True
+        assert queue.namespace.force_stop == True
